# Users

[Kaithemautomation Index](./README.md#kaithemautomation-index) / Users

> Auto-generated documentation for [users](../../../api/users.py) module.

- [Users](#users)
  - [list_all_permissions](#list_all_permissions)

## list_all_permissions

[Show source in users.py:6](../../../api/users.py#L6)

Return a dict of all permissions.
They will all have a description item

#### Signature

```python
def list_all_permissions() -> dict[str, dict[str, Any]]: ...
```